export default {
    addClass,
    removeClass,
    elementClass,
    getElementClass,
    oneOf
}

function addClass(el, className) {
    if (el.classList)
        el.classList.add(className);
    else
        el.className += ' ' + className;
}

function removeClass(el, className) {
    if (el.classList)
        el.classList.remove(className);
    else
        el.className = el.className.replace(new RegExp('(^|\\b)' + className.split(' ').join('|') + '(\\b|$)', 'gi'), ' ');
}

function elementClass(obj) {
    return getElementClass(obj.bsClass, obj.bsStyle, obj.bsSize);
}

function getElementClass(prefix, style, size) {
    let result = {
        [prefix]: true
    };

    if (style) {
        result[`${prefix}-${style}`] = true;
    }

    if (size) {
        let bsSize = SIZE_MAP[size];
        result[`${prefix}-${bsSize}`] = true;
    }

    return result;
}

function oneOf(values) {
    return (val) => {
        for (let validVal of values) {
            if (val === validVal) {
                return true;
            }
        }

        return false;
    }
}

export const SIZE_MAP = {
    large: 'lg',
    medium: 'md',
    small: 'sm',
    xsmall: 'xs',
    lg: 'lg',
    md: 'md',
    sm: 'sm',
    xs: 'xs',
};